News for hackers. Stuff that matters.
Re:ARMv7 vs. x86-64: Pathfinding benchmark of C++, D, Go, Ni... by super_tycoon on Saturday December 20, 2014 @09:16AM (#8776667)
I refactored it to be more static and final/const. Also used an int[][] for the node data.

Original comment is on proggit. Went from 1600ms to 900ms.

http://pastebin.com/w2BC8fNg

http://www.reddit.com/r/programming/comments/2pvf68/armv7_vs...

There are no comments on this comment yet.